@@ -10,6 +10,7 @@ index((aggregate_all), 3, aggregate, aggregate).
 index((aggregate_all), 4, aggregate, aggregate).
 index((free_variables), 4, aggregate, aggregate).
 index((ansi_format), 3, ansi_term, ansi_term).
+index((ansi_get_color), 2, ansi_term, ansi_term).
 index((include), 3, apply, apply).
 index((exclude), 3, apply, apply).
 index((partition), 4, apply, apply).
@@ -41,6 +42,7 @@ index((archive_set_header_property), 2, archive, archive).
 index((archive_extract), 3, archive, archive).
 index((archive_entries), 2, archive, archive).
 index((archive_data_stream), 3, archive, archive).
+index((archive_foldl), 4, archive, archive).
 index((arithmetic_function), 1, arithmetic, arithmetic).
 index((arithmetic_expression_value), 2, arithmetic, arithmetic).
 index((empty_assoc), 1, assoc, assoc).
@@ -61,6 +63,9 @@ index((put_assoc), 4, assoc, assoc).
 index((del_assoc), 4, assoc, assoc).
 index((del_min_assoc), 4, assoc, assoc).
 index((del_max_assoc), 4, assoc, assoc).
+index((restyle_identifier), 3, atom, atom).
+index((identifier_parts), 2, atom, atom).
+index((join_identifier_parts), 3, atom, atom).
 index(('$arch'), 2, backward_compatibility, backcomp).
 index(('$version'), 1, backward_compatibility, backcomp).
 index(('$home'), 1, backward_compatibility, backcomp).
@@ -92,8 +97,6 @@ index((flush), 0, backward_compatibility, backcomp).
 index((write_ln), 1, backward_compatibility, backcomp).
 index((proper_list), 1, backward_compatibility, backcomp).
 index((free_variables), 2, backward_compatibility, backcomp).
-index((subsumes_chk), 2, backward_compatibility, backcomp).
-index((subsumes), 2, backward_compatibility, backcomp).
 index((hash_term), 2, backward_compatibility, backcomp).
 index((checklist), 2, backward_compatibility, backcomp).
 index((sublist), 3, backward_compatibility, backcomp).
@@ -117,6 +120,8 @@ index((hash), 1, backward_compatibility, backcomp).
 index((set_base_module), 1, backward_compatibility, backcomp).
 index((eval_license), 0, backward_compatibility, backcomp).
 index((trie_insert_new), 3, backward_compatibility, backcomp).
+index((thread_at_exit), 1, backward_compatibility, backcomp).
+index((read_history), 6, backward_compatibility, backcomp).
 index((base32), 2, base32, base32).
 index((base32), 3, base32, base32).
 index((base64_encoded), 3, base64, base64).
@@ -172,20 +177,25 @@ index((list_undefined), 0, check, check).
 index((list_undefined), 1, check, check).
 index((list_autoload), 0, check, check).
 index((list_redefined), 0, check, check).
+index((list_cross_module_calls), 0, check, check).
+index((list_cross_module_calls), 1, check, check).
 index((list_void_declarations), 0, check, check).
 index((list_trivial_fails), 0, check, check).
 index((list_trivial_fails), 1, check, check).
+index((list_format_errors), 0, check, check).
+index((list_format_errors), 1, check, check).
 index((list_strings), 0, check, check).
 index((list_strings), 1, check, check).
+index((list_rationals), 0, check, check).
+index((list_rationals), 1, check, check).
 index((check_installation), 0, check_installation, check_installation).
 index((check_installation), 1, check_installation, check_installation).
+index((check_config_files), 0, check_installation, check_installation).
+index((update_config_files), 0, check_installation, check_installation).
+index((test_installation), 0, check_installation, check_installation).
+index((test_installation), 1, check_installation, check_installation).
 index((check_old_last), 0, checklast, checklast).
 index((check_old_select), 0, checkselect, checkselect).
-index((chr_show_store), 1, chr, chr).
-index((find_chr_constraint), 1, chr, chr).
-index((chr_trace), 0, chr, chr).
-index((chr_notrace), 0, chr, chr).
-index((chr_leash), 1, chr, chr).
 index((format_to_codes), 3, codesio, codesio).
 index((format_to_codes), 4, codesio, codesio).
 index((write_to_codes), 2, codesio, codesio).
@@ -233,6 +243,7 @@ index((csv), 3, csv, csv).
 index((csv), 4, csv, csv).
 index((csv_read_file), 2, csv, csv).
 index((csv_read_file), 3, csv, csv).
+index((csv_read_stream), 3, csv, csv).
 index((csv_read_file_row), 3, csv, csv).
 index((csv_read_row), 3, csv, csv).
 index((csv_options), 2, csv, csv).
@@ -281,6 +292,7 @@ index((expects_dialect), 1, prolog_dialect, dialect).
 index((exists_source), 1, prolog_dialect, dialect).
 index((source_exports), 2, prolog_dialect, dialect).
 index((dicts_same_tag), 2, dicts, dicts).
+index((dict_size), 2, dicts, dicts).
 index((dict_keys), 2, dicts, dicts).
 index((dicts_same_keys), 2, dicts, dicts).
 index((dicts_to_same_keys), 3, dicts, dicts).
@@ -329,16 +341,16 @@ index((el_history_events), 2, editline, editline).
 index((el_add_history), 2, editline, editline).
 index((el_write_history), 2, editline, editline).
 index((el_read_history), 2, editline, editline).
+index((instantiation_error), 1, error, error).
+index((uninstantiation_error), 1, error, error).
 index((type_error), 2, error, error).
 index((domain_error), 2, error, error).
 index((existence_error), 2, error, error).
 index((existence_error), 3, error, error).
 index((permission_error), 3, error, error).
-index((instantiation_error), 1, error, error).
-index((uninstantiation_error), 1, error, error).
 index((representation_error), 1, error, error).
-index((syntax_error), 1, error, error).
 index((resource_error), 1, error, error).
+index((syntax_error), 1, error, error).
 index((must_be), 2, error, error).
 index((is_of_type), 2, error, error).
 index((current_type), 3, error, error).
@@ -356,6 +368,7 @@ index((link_file), 3, files_ex, filesex).
 index((chmod), 2, files_ex, filesex).
 index((relative_file_name), 3, files_ex, filesex).
 index((directory_file_path), 3, files_ex, filesex).
+index((directory_member), 3, files_ex, filesex).
 index((copy_file), 2, files_ex, filesex).
 index((make_directory_path), 1, files_ex, filesex).
 index((copy_directory), 2, files_ex, filesex).
@@ -383,6 +396,18 @@ index((git_show), 4, git, git).
 index((git_commit_data), 3, git, git).
 index((open_hash_stream), 3, hash_stream, hash_stream).
 index((stream_hash), 2, hash_stream, hash_stream).
+index((ht_new), 1, hashtable, hashtable).
+index((ht_is_hashtable), 1, hashtable, hashtable).
+index((ht_size), 2, hashtable, hashtable).
+index((ht_put), 3, hashtable, hashtable).
+index((ht_update), 4, hashtable, hashtable).
+index((ht_put_new), 3, hashtable, hashtable).
+index((ht_put), 5, hashtable, hashtable).
+index((ht_del), 3, hashtable, hashtable).
+index((ht_get), 3, hashtable, hashtable).
+index((ht_gen), 3, hashtable, hashtable).
+index((ht_pairs), 2, hashtable, hashtable).
+index((ht_keys), 2, hashtable, hashtable).
 index((add_to_heap), 4, heaps, heaps).
 index((delete_from_heap), 4, heaps, heaps).
 index((empty_heap), 1, heaps, heaps).
@@ -395,19 +420,37 @@ index((merge_heaps), 3, heaps, heaps).
 index((min_of_heap), 3, heaps, heaps).
 index((min_of_heap), 5, heaps, heaps).
 index((singleton_heap), 3, heaps, heaps).
-index((help), 1, online_help, help).
-index((help), 0, online_help, help).
-index((apropos), 1, online_help, help).
-index((predicate), 5, help_index, helpidx).
-index((section), 4, help_index, helpidx).
-index((function), 3, help_index, helpidx).
+index((help), 0, prolog_help, help).
+index((help), 1, prolog_help, help).
+index((apropos), 1, prolog_help, help).
 index((load_hotfixes), 1, prolog_hotfix, hotfix).
+index((incr_assert), 1, increval, increval).
+index((incr_asserta), 1, increval, increval).
+index((incr_assertz), 1, increval, increval).
+index((incr_retractall), 1, increval, increval).
+index((incr_retract), 1, increval, increval).
+index((is_incremental_subgoal), 1, increval, increval).
+index((incr_directly_depends), 2, increval, increval).
+index((incr_trans_depends), 2, increval, increval).
+index((incr_invalid_subgoals), 1, increval, increval).
+index((incr_is_invalid), 1, increval, increval).
+index((incr_invalidate_call), 1, increval, increval).
+index((incr_invalidate_calls), 1, increval, increval).
+index((incr_table_update), 0, increval, increval).
+index((incr_propagate_calls), 1, increval, increval).
+index((intercept), 3, intercept, intercept).
+index((intercept), 4, intercept, intercept).
+index((intercept_all), 4, intercept, intercept).
+index((nb_intercept_all), 4, intercept, intercept).
+index((send_signal), 1, intercept, intercept).
+index((send_silent_signal), 1, intercept, intercept).
 index((open_any), 5, iostream, iostream).
 index((close_any), 1, iostream, iostream).
 index((iso_639_2), 2, iso_639, iso_639).
 index((iso_639_3), 2, iso_639, iso_639).
 index((iso_639), 2, iso_639, iso_639).
 index((isub), 4, isub, isub).
+index(('$isub'), 5, isub, isub).
 index((lazy_list), 2, lazy_lists, lazy_lists).
 index((lazy_list), 3, lazy_lists, lazy_lists).
 index((lazy_list_materialize), 1, lazy_lists, lazy_lists).
@@ -422,10 +465,12 @@ index((lazy_engine_next), 4, lazy_lists, lazy_lists).
 index((lazy_list_iterator), 4, lazy_lists, lazy_lists).
 index((listing), 0, prolog_listing, listing).
 index((listing), 1, prolog_listing, listing).
+index((listing), 2, prolog_listing, listing).
 index((portray_clause), 1, prolog_listing, listing).
 index((portray_clause), 2, prolog_listing, listing).
 index((portray_clause), 3, prolog_listing, listing).
 index((member), 2, lists, lists).
+index((memberchk), 2, lists, lists).
 index((append), 2, lists, lists).
 index((append), 3, lists, lists).
 index((prefix), 2, lists, lists).
@@ -445,8 +490,11 @@ index((same_length), 2, lists, lists).
 index((reverse), 2, lists, lists).
 index((permutation), 2, lists, lists).
 index((flatten), 2, lists, lists).
+index((clumped), 2, lists, lists).
 index((max_member), 2, lists, lists).
 index((min_member), 2, lists, lists).
+index((max_member), 3, lists, lists).
+index((min_member), 3, lists, lists).
 index((sum_list), 2, lists, lists).
 index((max_list), 2, lists, lists).
 index((min_list), 2, lists, lists).
@@ -459,6 +507,8 @@ index((subset), 2, lists, lists).
 index((subtract), 3, lists, lists).
 index((main), 0, prolog_main, main).
 index((argv_options), 3, prolog_main, main).
+index((cli_parse_debug_options), 2, prolog_main, main).
+index((cli_enable_development_system), 0, prolog_main, main).
 index((make), 0, make, make).
 index((md5_hash), 3, md5, md5).
 index((new_memory_file), 1, memory_file, memfile).
@@ -480,6 +530,10 @@ index((memory_file_substring), 5, memory_file, memfile).
 index((memory_file_line_position), 4, memory_file, memfile).
 index((utf8_position_memory_file), 3, memory_file, memfile).
 index((in_temporary_module), 3, modules, modules).
+index((current_temporary_module), 1, modules, modules).
+index((mqi_start), 0, mqi, mqi).
+index((mqi_start), 1, mqi, mqi).
+index((mqi_stop), 1, mqi, mqi).
 index((nb_rb_insert), 3, nb_rbtrees, nb_rbtrees).
 index((nb_rb_get_node), 3, nb_rbtrees, nb_rbtrees).
 index((nb_rb_node_value), 2, nb_rbtrees, nb_rbtrees).
@@ -498,6 +552,7 @@ index((occurrences_of_term), 3, occurs, occurs).
 index((occurrences_of_var), 3, occurs, occurs).
 index((sub_term), 2, occurs, occurs).
 index((sub_var), 2, occurs, occurs).
+index((sub_term_shared_variables), 3, occurs, occurs).
 index((odbc_connect), 3, odbc, odbc).
 index((odbc_driver_connect), 3, odbc, odbc).
 index((odbc_disconnect), 1, odbc, odbc).
@@ -513,6 +568,7 @@ index((odbc_prepare), 5, odbc, odbc).
 index((odbc_execute), 2, odbc, odbc).
 index((odbc_execute), 3, odbc, odbc).
 index((odbc_fetch), 3, odbc, odbc).
+index((odbc_next_result_set), 1, odbc, odbc).
 index((odbc_close_statement), 1, odbc, odbc).
 index((odbc_clone_statement), 2, odbc, odbc).
 index((odbc_free_statement), 1, odbc, odbc).
@@ -525,6 +581,7 @@ index((odbc_type), 3, odbc, odbc).
 index((odbc_data_source), 2, odbc, odbc).
 index((odbc_table_primary_key), 3, odbc, odbc).
 index((odbc_table_foreign_key), 5, odbc, odbc).
+index((odbc_set_option), 1, odbc, odbc).
 index((odbc_statistics), 1, odbc, odbc).
 index((odbc_debug), 1, odbc, odbc).
 index((push_operators), 1, prolog_operator, operators).
@@ -578,6 +635,19 @@ index((pairs_keys), 2, pairs, pairs).
 index((group_pairs_by_key), 2, pairs, pairs).
 index((transpose_pairs), 2, pairs, pairs).
 index((map_list_to_pairs), 3, pairs, pairs).
+index((paxos_get), 1, paxos, paxos).
+index((paxos_get), 2, paxos, paxos).
+index((paxos_get), 3, paxos, paxos).
+index((paxos_set), 1, paxos, paxos).
+index((paxos_set), 2, paxos, paxos).
+index((paxos_set), 3, paxos, paxos).
+index((paxos_on_change), 2, paxos, paxos).
+index((paxos_on_change), 3, paxos, paxos).
+index((paxos_initialize), 1, paxos, paxos).
+index((paxos_admin_key), 2, paxos, paxos).
+index((paxos_property), 1, paxos, paxos).
+index((paxos_quorum_ask), 4, paxos, paxos).
+index((paxos_replicate_key), 3, paxos, paxos).
 index((re_match), 2, pcre, pcre).
 index((re_match), 3, pcre, pcre).
 index((re_matchsub), 4, pcre, pcre).
@@ -591,6 +661,7 @@ index((re_config), 1, pcre, pcre).
 index((pdt_install_console), 0, pdt_console, pdt_console).
 index((pengine_writeln), 1, pengines_io, pengines_io).
 index((pengine_nl), 0, pengines_io, pengines_io).
+index((pengine_tab), 1, pengines_io, pengines_io).
 index((pengine_flush_output), 0, pengines_io, pengines_io).
 index((pengine_format), 1, pengines_io, pengines_io).
 index((pengine_format), 2, pengines_io, pengines_io).
@@ -609,6 +680,7 @@ index((pengine_read_line_to_codes), 2, pengines_io, pengines_io).
 index((pengine_io_predicate), 1, pengines_io, pengines_io).
 index((pengine_bind_io_to_html), 1, pengines_io, pengines_io).
 index((pengine_io_goal_expansion), 2, pengines_io, pengines_io).
+index((message_lines_to_html), 3, pengines_io, pengines_io).
 index((persistent), 1, persistency, persistency).
 index((current_persistent_predicate), 1, persistency, persistency).
 index((db_attach), 2, persistency, persistency).
@@ -626,6 +698,7 @@ index((run_tests), 0, plunit, plunit).
 index((run_tests), 1, plunit, plunit).
 index((load_test_files), 1, plunit, plunit).
 index((running_tests), 0, plunit, plunit).
+index((current_test), 5, plunit, plunit).
 index((test_report), 1, plunit, plunit).
 index((porter_stem), 2, porter_stem, porter_stem).
 index((unaccent_atom), 2, porter_stem, porter_stem).
@@ -633,6 +706,8 @@ index((tokenize_atom), 2, porter_stem, porter_stem).
 index((atom_to_stem_list), 2, porter_stem, porter_stem).
 index((portray_text), 1, portray_text, portray_text).
 index((set_portray_text), 2, portray_text, portray_text).
+index((set_portray_text), 3, portray_text, portray_text).
+index(('$portray_text_enabled'), 1, portray_text, portray_text).
 index((print_term), 2, prolog_pretty_print, pprint).
 index((predicate_options), 3, predicate_options, predicate_options).
 index((assert_predicate_options), 4, predicate_options, predicate_options).
@@ -657,28 +732,57 @@ index((process_kill), 1, process, process).
 index((process_group_kill), 1, process, process).
 index((process_group_kill), 2, process, process).
 index((process_kill), 2, process, process).
-index((autoload), 0, prolog_autoload, prolog_autoload).
-index((autoload), 1, prolog_autoload, prolog_autoload).
+index((process_set_method), 1, process, process).
+index((autoload_all), 0, prolog_autoload, prolog_autoload).
+index((autoload_all), 1, prolog_autoload, prolog_autoload).
 index((set_breakpoint), 4, prolog_breakpoints, prolog_breakpoints).
 index((set_breakpoint), 5, prolog_breakpoints, prolog_breakpoints).
 index((delete_breakpoint), 1, prolog_breakpoints, prolog_breakpoints).
 index((breakpoint_property), 2, prolog_breakpoints, prolog_breakpoints).
 index((clause_info), 4, prolog_clause, prolog_clause).
+index((clause_info), 5, prolog_clause, prolog_clause).
 index((initialization_layout), 4, prolog_clause, prolog_clause).
 index((predicate_name), 2, prolog_clause, prolog_clause).
 index((clause_name), 2, prolog_clause, prolog_clause).
+index((comma_list), 2, prolog_code, prolog_code).
+index((semicolon_list), 2, prolog_code, prolog_code).
+index((mkconj), 3, prolog_code, prolog_code).
+index((mkdisj), 3, prolog_code, prolog_code).
+index((pi_head), 2, prolog_code, prolog_code).
+index((head_name_arity), 3, prolog_code, prolog_code).
+index((most_general_goal), 2, prolog_code, prolog_code).
+index((extend_goal), 3, prolog_code, prolog_code).
+index((predicate_label), 2, prolog_code, prolog_code).
+index((predicate_sort_key), 2, prolog_code, prolog_code).
+index((is_control_goal), 1, prolog_code, prolog_code).
+index((is_predicate_indicator), 1, prolog_code, prolog_code).
+index((body_term_calls), 2, prolog_code, prolog_code).
 index((prolog_walk_code), 1, prolog_codewalk, prolog_codewalk).
 index((prolog_program_clause), 2, prolog_codewalk, prolog_codewalk).
 index((prolog_colourise_stream), 3, prolog_colour, prolog_colour).
+index((prolog_colourise_stream), 4, prolog_colour, prolog_colour).
 index((prolog_colourise_term), 4, prolog_colour, prolog_colour).
 index((prolog_colourise_query), 3, prolog_colour, prolog_colour).
 index((syntax_colour), 2, prolog_colour, prolog_colour).
 index((syntax_message), 3, prolog_colour, prolog_colour).
+index((prolog_dump_runtime_variables), 0, prolog_config, prolog_config).
+index((apple_bundle_libdir), 1, prolog_config, prolog_config).
+index((spy), 1, prolog_debug_tools, prolog_debug).
+index((nospy), 1, prolog_debug_tools, prolog_debug).
+index((nospyall), 0, prolog_debug_tools, prolog_debug).
+index((debugging), 0, prolog_debug_tools, prolog_debug).
+index((trap), 1, prolog_debug_tools, prolog_debug).
+index((notrap), 1, prolog_debug_tools, prolog_debug).
+index((file_autoload_directives), 3, prolog_deps, prolog_deps).
+index((file_auto_import), 2, prolog_deps, prolog_deps).
 index((format_spec), 2, prolog_format, prolog_format).
 index((format_spec), 3, prolog_format, prolog_format).
 index((format_types), 2, prolog_format, prolog_format).
 index((prolog_history), 1, prolog_history, prolog_history).
 index((qcompile_libraries), 0, prolog_install, prolog_install).
+index((cmake_qcompile), 0, prolog_install, prolog_install).
+index((cmake_qcompile), 2, prolog_install, prolog_install).
+index((cmake_save_man_index), 0, prolog_install, prolog_install).
 index((jiti_list), 0, prolog_jiti, prolog_jiti).
 index((jiti_list), 1, prolog_jiti, prolog_jiti).
 index((infer_meta_predicate), 2, prolog_metainference, prolog_metainference).
@@ -694,6 +798,7 @@ index((pack_rebuild), 1, prolog_pack, prolog_pack).
 index((pack_rebuild), 0, prolog_pack, prolog_pack).
 index((pack_remove), 1, prolog_pack, prolog_pack).
 index((pack_property), 2, prolog_pack, prolog_pack).
+index((pack_attach), 2, prolog_pack, prolog_pack).
 index((pack_url_file), 2, prolog_pack, prolog_pack).
 index((prolog_server), 2, prolog_server, prolog_server).
 index((prolog_read_source_term), 4, prolog_source, prolog_source).
@@ -713,10 +818,18 @@ index((print_prolog_backtrace), 2, prolog_stack, prolog_stack).
 index((print_prolog_backtrace), 3, prolog_stack, prolog_stack).
 index((backtrace), 1, prolog_stack, prolog_stack).
 index((open_prolog_stream), 4, prolog_stream, prolog_stream).
+index((trace), 1, prolog_trace, prolog_trace).
+index((trace), 2, prolog_trace, prolog_trace).
+index((tracing), 2, prolog_trace, prolog_trace).
+index((notraceall), 0, prolog_trace, prolog_trace).
+index((wrap_predicate), 4, prolog_wrap, prolog_wrap).
+index((unwrap_predicate), 2, prolog_wrap, prolog_wrap).
+index((current_predicate_wrapper), 4, prolog_wrap, prolog_wrap).
 index((xref_source), 1, prolog_xref, prolog_xref).
 index((xref_source), 2, prolog_xref, prolog_xref).
 index((xref_called), 3, prolog_xref, prolog_xref).
 index((xref_called), 4, prolog_xref, prolog_xref).
+index((xref_called), 5, prolog_xref, prolog_xref).
 index((xref_defined), 3, prolog_xref, prolog_xref).
 index((xref_definition_line), 2, prolog_xref, prolog_xref).
 index((xref_exported), 2, prolog_xref, prolog_xref).
@@ -745,6 +858,10 @@ index((xref_used_class), 2, prolog_xref, prolog_xref).
 index((xref_defined_class), 3, prolog_xref, prolog_xref).
 index((protobuf_message), 2, protobufs, protobufs).
 index((protobuf_message), 3, protobufs, protobufs).
+index((protobuf_parse_from_codes), 3, protobufs, protobufs).
+index((protobuf_serialize_to_codes), 3, protobufs, protobufs).
+index((protobuf_field_is_map), 2, protobufs, protobufs).
+index((protobuf_map_pairs), 3, protobufs, protobufs).
 index((phrase_from_file), 2, pure_input, pure_input).
 index((phrase_from_file), 3, pure_input, pure_input).
 index((phrase_from_stream), 2, pure_input, pure_input).
@@ -851,8 +968,7 @@ index((load_rdf), 2, rdf, rdf).
 index((load_rdf), 3, rdf, rdf).
 index((xml_to_rdf), 3, rdf, rdf).
 index((process_rdf), 3, rdf, rdf).
-index((load_rdf_ntriples), 2, rdf_ntriples_old, rdf_ntriples).
-index((rdf_ntriple_part), 4, rdf_ntriples_old, rdf_ntriples).
+index((rdf_diagram_from_file), 1, rdf_diagram, rdf_diagram).
 index((xml_to_plrdf), 3, rdf_parser, rdf_parser).
 index((element_to_plrdf), 3, rdf_parser, rdf_parser).
 index((make_rdf_state), 3, rdf_parser, rdf_parser).
@@ -883,9 +999,41 @@ index((read_file_to_terms), 3, read_util, readutil).
 index((record), 1, record, record).
 index((current_record), 2, record, record).
 index((current_record_predicate), 2, record, record).
-index((rewrite), 2, rewrite, rewrite).
-index((rew_term_expansion), 2, rewrite, rewrite).
-index((rew_goal_expansion), 2, rewrite, rewrite).
+index((redis_server), 3, redis, redis).
+index((redis_connect), 1, redis, redis).
+index((redis_connect), 3, redis, redis).
+index((redis_disconnect), 1, redis, redis).
+index((redis_disconnect), 2, redis, redis).
+index((redis), 1, redis, redis).
+index((redis), 2, redis, redis).
+index((redis), 3, redis, redis).
+index((redis_get_list), 3, redis, redis).
+index((redis_get_list), 4, redis, redis).
+index((redis_set_list), 3, redis, redis).
+index((redis_get_hash), 3, redis, redis).
+index((redis_set_hash), 3, redis, redis).
+index((redis_scan), 3, redis, redis).
+index((redis_sscan), 4, redis, redis).
+index((redis_hscan), 4, redis, redis).
+index((redis_zscan), 4, redis, redis).
+index((redis_subscribe), 4, redis, redis).
+index((redis_subscribe), 2, redis, redis).
+index((redis_unsubscribe), 2, redis, redis).
+index((redis_current_subscription), 2, redis, redis).
+index((redis_write), 2, redis, redis).
+index((redis_read), 2, redis, redis).
+index((redis_array_dict), 3, redis, redis).
+index((redis_property), 2, redis, redis).
+index((redis_current_command), 2, redis, redis).
+index((redis_current_command), 3, redis, redis).
+index((xstream_set), 3, redis_streams, redis_streams).
+index((xadd), 4, redis_streams, redis_streams).
+index((xlisten), 3, redis_streams, redis_streams).
+index((xlisten_group), 5, redis_streams, redis_streams).
+index((xconsumer_stop), 1, redis_streams, redis_streams).
+index((rewrite_term), 2, rewrite_term, rewrite_term).
+index((rew_term_expansion), 2, rewrite_term, rewrite_term).
+index((rew_goal_expansion), 2, rewrite_term, rewrite_term).
 index((rlimit), 3, clib_rlimit, rlimit).
 index((saml_authenticate), 4, saml, saml).
 index((safe_goal), 1, sandbox, sandbox).
@@ -972,6 +1120,7 @@ index((current_foreign_library), 2, shlib, shlib).
 index((reload_foreign_libraries), 0, shlib, shlib).
 index((use_foreign_library), 1, shlib, shlib).
 index((use_foreign_library), 2, shlib, shlib).
+index((win_add_dll_directory), 1, shlib, shlib).
 index((snowball), 3, snowball, snowball).
 index((snowball_current_algorithm), 1, snowball, snowball).
 index((tcp_socket), 1, socket, socket).
@@ -985,6 +1134,7 @@ index((tcp_accept), 3, socket, socket).
 index((tcp_listen), 2, socket, socket).
 index((tcp_fcntl), 3, socket, socket).
 index((tcp_setopt), 2, socket, socket).
+index((tcp_getopt), 2, socket, socket).
 index((tcp_host_to_address), 2, socket, socket).
 index((tcp_select), 3, socket, socket).
 index((gethostname), 1, socket, socket).
@@ -999,37 +1149,77 @@ index((reduced), 1, solution_sequences, solution_sequences).
 index((reduced), 3, solution_sequences, solution_sequences).
 index((limit), 2, solution_sequences, solution_sequences).
 index((offset), 2, solution_sequences, solution_sequences).
+index((call_nth), 2, solution_sequences, solution_sequences).
 index((order_by), 2, solution_sequences, solution_sequences).
 index((group_by), 4, solution_sequences, solution_sequences).
 index((predsort), 3, sort, sort).
 index((locale_sort), 2, sort, sort).
+index((certificate_field), 2, ssl, ssl).
 index((load_certificate), 2, ssl, ssl).
 index((load_private_key), 3, ssl, ssl).
 index((load_public_key), 2, ssl, ssl).
 index((load_crl), 2, ssl, ssl).
+index((write_certificate), 3, ssl, ssl).
 index((system_root_certificates), 1, ssl, ssl).
 index((cert_accept_any), 5, ssl, ssl).
+index((same_certificate), 2, ssl, ssl).
 index((ssl_context), 3, ssl, ssl).
 index((ssl_add_certificate_key), 4, ssl, ssl).
 index((ssl_set_options), 3, ssl, ssl).
+index((ssl_property), 2, ssl, ssl).
 index((ssl_negotiate), 5, ssl, ssl).
 index((ssl_peer_certificate), 2, ssl, ssl).
 index((ssl_peer_certificate_chain), 2, ssl, ssl).
 index((ssl_session), 2, ssl, ssl).
 index((ssl_secure_ciphers), 1, ssl, ssl).
+index((verify_certificate), 3, ssl, ssl).
+index((verify_certificate_issuer), 2, ssl, ssl).
+index((ssl_upgrade_legacy_options), 2, ssl, ssl).
 index((statistics), 0, prolog_statistics, statistics).
 index((statistics), 1, prolog_statistics, statistics).
 index((thread_statistics), 2, prolog_statistics, statistics).
 index((time), 1, prolog_statistics, statistics).
+index((call_time), 2, prolog_statistics, statistics).
+index((call_time), 3, prolog_statistics, statistics).
 index((profile), 1, prolog_statistics, statistics).
 index((profile), 2, prolog_statistics, statistics).
 index((show_profile), 1, prolog_statistics, statistics).
+index((profile_data), 1, prolog_statistics, statistics).
+index((profile_procedure_data), 2, prolog_statistics, statistics).
+index((stomp_connection), 5, stomp, stomp).
+index((stomp_connection), 6, stomp, stomp).
+index((stomp_connection_property), 2, stomp, stomp).
+index((stomp_destroy_connection), 1, stomp, stomp).
+index((stomp_connect), 1, stomp, stomp).
+index((stomp_connect), 2, stomp, stomp).
+index((stomp_teardown), 1, stomp, stomp).
+index((stomp_reconnect), 1, stomp, stomp).
+index((stomp_send), 4, stomp, stomp).
+index((stomp_send_json), 4, stomp, stomp).
+index((stomp_subscribe), 4, stomp, stomp).
+index((stomp_unsubscribe), 2, stomp, stomp).
+index((stomp_ack), 2, stomp, stomp).
+index((stomp_nack), 2, stomp, stomp).
+index((stomp_ack), 3, stomp, stomp).
+index((stomp_nack), 3, stomp, stomp).
+index((stomp_transaction), 2, stomp, stomp).
+index((stomp_disconnect), 2, stomp, stomp).
+index((stomp_begin), 2, stomp, stomp).
+index((stomp_commit), 2, stomp, stomp).
+index((stomp_abort), 2, stomp, stomp).
+index((stomp_setup), 2, stomp, stomp).
 index((stream_info), 1, stream_info, streaminfo).
 index((add_stream_to_pool), 2, stream_pool, streampool).
 index((delete_stream_from_pool), 1, stream_pool, streampool).
 index((close_stream_pool), 0, stream_pool, streampool).
 index((dispatch_stream_pool), 1, stream_pool, streampool).
 index((stream_pool_main_loop), 0, stream_pool, streampool).
+index((dedent_lines), 3, strings, strings).
+index((indent_lines), 3, strings, strings).
+index((indent_lines), 4, strings, strings).
+index((interpolate_string), 4, strings, strings).
+index((string_lines), 2, strings, strings).
+index((string), 4, strings, strings).
 index((openlog), 3, syslog, syslog).
 index((syslog), 2, syslog, syslog).
 index((syslog), 3, syslog, syslog).
@@ -1059,11 +1249,24 @@ index((sub_string), 3, table, table).
 index((table_version), 2, table, table).
 index((sort_table), 2, table_util, table_util).
 index((verify_table_order), 1, table_util, table_util).
-index((table), 1, tabling, tabling).
-index((current_table), 2, tabling, tabling).
-index((abolish_all_tables), 0, tabling, tabling).
-index((abolish_table_subgoals), 1, tabling, tabling).
-index((start_tabling), 2, tabling, tabling).
+index((abolish_all_tables), 0, tables, tables).
+index((abolish_module_tables), 1, tables, tables).
+index((abolish_table_pred), 1, tables, tables).
+index((abolish_table_call), 1, tables, tables).
+index((abolish_table_call), 2, tables, tables).
+index((abolish_table_subgoals), 2, tables, tables).
+index((tfindall), 3, tables, tables).
+index(('t not'), 1, tables, tables).
+index((get_call), 3, tables, tables).
+index((get_calls), 3, tables, tables).
+index((get_returns), 2, tables, tables).
+index((get_returns), 3, tables, tables).
+index((get_returns_and_dls), 3, tables, tables).
+index((get_returns_and_tvs), 3, tables, tables).
+index((get_returns_for_call), 2, tables, tables).
+index((get_residual), 2, tables, tables).
+index((set_pil_on), 0, tables, tables).
+index((set_pil_off), 0, tables, tables).
 index((term_hash), 2, terms, terms).
 index((term_hash), 4, terms, terms).
 index((term_size), 2, terms, terms).
@@ -1076,14 +1279,25 @@ index((cyclic_term), 1, terms, terms).
 index((acyclic_term), 1, terms, terms).
 index((term_subsumer), 3, terms, terms).
 index((term_factorized), 3, terms, terms).
+index((mapargs), 3, terms, terms).
+index((mapsubterms), 3, terms, terms).
+index((same_functor), 2, terms, terms).
+index((same_functor), 3, terms, terms).
+index((same_functor), 4, terms, terms).
 index((show_coverage), 1, prolog_cover, test_cover).
+index((show_coverage), 2, prolog_cover, test_cover).
 index((make_tests), 3, test_wizard, test_wizard).
 index((make_test), 3, test_wizard, test_wizard).
 index((concurrent), 3, thread, thread).
 index((concurrent_maplist), 2, thread, thread).
 index((concurrent_maplist), 3, thread, thread).
 index((concurrent_maplist), 4, thread, thread).
+index((concurrent_forall), 2, thread, thread).
+index((concurrent_forall), 3, thread, thread).
+index((concurrent_and), 2, thread, thread).
+index((concurrent_and), 3, thread, thread).
 index((first_solution), 3, thread, thread).
+index((call_in_thread), 2, thread, thread).
 index((thread_pool_create), 3, thread_pool, thread_pool).
 index((thread_pool_destroy), 1, thread_pool, thread_pool).
 index((thread_create_in_pool), 4, thread_pool, thread_pool).
@@ -1104,6 +1318,8 @@ index((tdebug), 1, thread_util, threadutil).
 index((tnodebug), 0, thread_util, threadutil).
 index((tnodebug), 1, thread_util, threadutil).
 index((tprofile), 1, thread_util, threadutil).
+index((tbacktrace), 1, thread_util, threadutil).
+index((tbacktrace), 2, thread_util, threadutil).
 index((alarm), 3, time, time).
 index((alarm), 4, time, time).
 index((alarm_at), 3, time, time).
@@ -1117,9 +1333,11 @@ index((call_with_time_limit), 2, time, time).
 index((tty_clear), 0, tty, tty).
 index((tty_flash), 0, tty, tty).
 index((menu), 3, tty, tty).
-index((udp_host_to_address), 2, udp_broadcast, udp_broadcast).
 index((udp_broadcast_initialize), 2, udp_broadcast, udp_broadcast).
-index((udp_broadcast_service), 2, udp_broadcast, udp_broadcast).
+index((udp_broadcast_close), 1, udp_broadcast, udp_broadcast).
+index((udp_peer_add), 2, udp_broadcast, udp_broadcast).
+index((udp_peer_del), 2, udp_broadcast, udp_broadcast).
+index((udp_peer), 2, udp_broadcast, udp_broadcast).
 index((add_edges), 3, ugraphs, ugraphs).
 index((add_vertices), 3, ugraphs, ugraphs).
 index((complement), 2, ugraphs, ugraphs).
@@ -1137,6 +1355,7 @@ index((transpose_ugraph), 2, ugraphs, ugraphs).
 index((vertices), 2, ugraphs, ugraphs).
 index((vertices_edges_to_ugraph), 3, ugraphs, ugraphs).
 index((ugraph_union), 3, ugraphs, ugraphs).
+index((connect_ugraph), 3, ugraphs, ugraphs).
 index((getuid), 1, uid, uid).
 index((getgid), 1, uid, uid).
 index((geteuid), 1, uid, uid).
@@ -1196,12 +1415,21 @@ index((url_iri), 2, url, url).
 index((file_name_to_url), 2, url, url).
 index((set_url_encoding), 2, url, url).
 index((utf8_codes), 3, utf8, utf8).
+index((uuid), 1, uuid, uuid).
+index((uuid), 2, uuid, uuid).
+index((uuid_property), 2, uuid, uuid).
 index((numbervars), 1, varnumbers, varnumbers).
 index((varnumbers), 2, varnumbers, varnumbers).
 index((max_var_number), 3, varnumbers, varnumbers).
 index((varnumbers), 3, varnumbers, varnumbers).
 index((varnumbers_names), 3, varnumbers, varnumbers).
 index((vm_list), 1, prolog_vm, vm).
+index((clause_vm), 2, prolog_vm, vm).
+index((vmi_labels), 2, prolog_vm, vm).
+index((call_residual_program), 2, wfs, wfs).
+index((call_delays), 2, wfs, wfs).
+index((delays_residual_program), 2, wfs, wfs).
+index((answer_residual), 2, wfs, wfs).
 index((when), 2, when, when).
 index((init_win_menus), 0, win_menu, win_menu).
 index((writef), 1, writef, writef).
@@ -1240,6 +1468,15 @@ index((/), 9, yall, yall).
 index((lambda_calls), 2, yall, yall).
 index((lambda_calls), 3, yall, yall).
 index((is_lambda), 1, yall, yall).
+index((zip_open), 4, zip, zip).
+index((zip_close), 1, zip, zip).
+index((zip_close), 2, zip, zip).
+index((with_zipper), 2, zip, zip).
+index((zipper_open_new_file_in_zip), 4, zip, zip).
+index((zipper_goto), 2, zip, zip).
+index((zipper_open_current), 3, zip, zip).
+index((zipper_members), 2, zip, zip).
+index((zipper_file_info), 3, zip, zip).
 index((zopen), 3, zlib, zlib).
 index((gzopen), 3, zlib, zlib).
 index((gzopen), 4, zlib, zlib).
